# Wasserstein

[![build-wheels](https://github.com/pkomiske/Wasserstein/actions/workflows/build-wheels.yml/badge.svg)](https://github.com/pkomiske/Wasserstein/actions)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pkomiske/Wasserstein/master)

[![PyPI version](https://badge.fury.io/py/Wasserstein.svg)](https://pypi.org/project/Wasserstein/)
[![python versions](https://img.shields.io/pypi/pyversions/Wasserstein)](https://pypi.org/project/Wasserstein/)

Python/C++ library for computing Wasserstein distances efficiently. See the [documentation](https://pkomiske.github.io/Wasserstein/).

Copyright (C) 2019-2021 Patrick T. Komiske III